
// 入力エラー時の
var inputColorCode = {
	'error'   : 'rgba(255,174,174,0.5)',  // #ffaeaeエラー時
	'success' : '#daffae',  // 成功時
	'normal'  : '#ffffff',  // 通常時
	'focus'   : '#ffffd6'   // フォーカス時
};

/*
 * エラー時のCSS定義
$(".errorMessage").css({
	'color'     : '#ff0000',
	'font-size' : '12px',
	'padding'   : '20px',
	'text-align': 'left'
});
 */

// エラーメッセージの初期非表示処理
$("tr.errors").hide();

/*
 * デフォルトの入力フォームカラー設定
 */
$(":input").css('background', inputColorCode.normal);


/*
 * 入力文字のエスケープ関数
 */
function htmlspecialchars(ch) {
	ch = ch.replace(/&/g,"&amp;") ;
	ch = ch.replace(/"/g,"&quot;") ;
	ch = ch.replace(/'/g,"&#039;") ;
	ch = ch.replace(/</g,"&lt;") ;
	ch = ch.replace(/>/g,"&gt;") ;
	return ch ;
};



/*
 * 入力フォームエラーチェック用オブジェクト
 */
var check = {

	// 空文字チェック用正規表現
	spaceRegExp     :   /(\s|\t|\r|\n|　)*/g,

	// 電話番号チェック用正規表現
	phoneRegExp     :   /^\d{9,11}$/,

	// メールアドレスチェック用正規表現
	mailRegExp      :   /^([a-zA-Z0-9])+([a-zA-Z0-9\._-])*@([a-zA-Z0-9_-])+([a-zA-Z0-9\._-]+)+$/,

	// カタカナ入力チェック用正規表現
	kanaRegExp      :   /^[ァ-ロワヲンー]*$/,

	// エラーメッセージフラグ
	messageFlag     :   false,

	// 定期購入・通常購入・お試し購入の判別数値
	buyTypeNum      :   0,
	// エラーメッセージ
	errorsMessage   :   {
		ItemNotSelected         : "購入する商品を選択してください",
		reguryPaseNotSelected   : "配送ペースを選択してください",
		familyNameEmpty         : "お届け先の姓を入力してください",
		familyNameKanaEmpty     : "お届け先の姓(カナ)を入力してください",
		familyNameKanaFormat    : "お届け先の姓(カナ)を全角カタカナで正しく入力してください",
		givenNameEmpty          : "お届け先の名を入力してください",
		givenNameKanaEmpty      : "お届け先の名(カナ)を入力してください",
		givenNameKanaFormat     : "お届け先の名(カナ)を全角カタカナで正しく入力してください",
		postalCodeFormat        : "お届け先の郵便番号を半角数字7ケタで正しく入力してください",
		prefNotSelected         : "お届け先の都道府県を選択してください",
		address1Empty           : "お届け先の住所(市町村区・番地)を入力してください",
		phoneFormat             : "お届け先の電話番号を半角数字で正しく入力してください",
		emailFormat             : "Eメールアドレスを正しく入力してください",
		privacyPolicyNotChecked : "個人情報保護方針に同意してください",
		paymentNotSelected      : "決済方法を選択してください",
		familyNameEmpty2        : "ご請求先の姓を入力してください",
		familyNameKanaEmpty2    : "ご請求先の姓(カナ)を入力してください",
		familyNameKanaFormat2   : "ご請求先の姓(カナ)を全角カタカナで正しく入力してください",
		givenNameEmpty2         : "ご請求先の名を入力してください",
		givenNameKanaEmpty2     : "ご請求先の名(カナ)を入力してください",
		givenNameKanaFormat2    : "ご請求先の名(カナ)を全角カタカナで正しく入力してください",
		postalCodeFormat2       : "ご請求先の郵便番号を半角数字7ケタで正しく入力してください",
		prefNotSelected2        : "ご請求先の都道府県を選択してください",
		address1Empty2          : "ご請求先の住所(市町村区・番地)を入力してください",
		phoneFormat2            : "ご請求先の電話番号を半角数字で正しく入力してください",
	},

	// 姓
	'family_name'       :   function(data) {
		if(!data.replace(this.spaceRegExp, ''))
			return 'familyNameEmpty';
		return true;
	},

	// 名
	'given_name'        :   function(data) {
		if(!data.replace(this.spaceRegExp, ''))
			return 'givenNameEmpty';
		return true;
	},

	// 姓カナ
	'family_name_kana'  :   function(data) {
		if(!data.replace(this.spaceRegExp, ''))
			return 'familyNameKanaEmpty';
		else if(!this.kanaRegExp.test(data.replace(this.spaceRegExp, '')))
			return 'familyNameKanaFormat';
		return true;
	},

	// 名カナ
	'given_name_kana'   :   function(data) {
		if(!data.replace(this.spaceRegExp, ''))
			return 'givenNameKanaEmpty';
		else if(!this.kanaRegExp.test(data.replace(this.spaceRegExp, '')))
			return 'givenNameKanaFormat';
		return true;
	},

	// 郵便番号
	'postal_code'       :   function(data) {
		if(!/^\d{7}$/.test(data.replace(/\-/g, '')))
			return 'postalCodeFormat';
		return true;
	},

	// 住所1
	'address1'          :   function(data) {
		if(!data.replace(this.spaceRegExp, ''))
			return 'address1Empty';
		return true;
	},

	/*
	// 住所2
	'address2'          :   function(data) {
	if(!data.replace(this.spaceRegExp, ''))
	return false;
	return true;
	},
	*/

	// 電話番号
	'tel'               :   function(data) {
		if(!this.phoneRegExp.test(data.replace(/\-/g, '')))
			return 'phoneFormat';
		return true;
	},

	// メールアドレス
	'email'      :   function(data) {
		if(!this.mailRegExp.test(data))
			return 'emailFormat';
		return true;
	},

	// 都道府県
	'pref'              :   function(data) {
		if(!data)
			return 'prefNotSelected';
		return true;
	},

	/*
	//配送ペース
	'regury_pase'              :   function(regury_pase) {
	if(!regury_pase)
	return false;
	return true;
	},*/

	// 商品の選択

	/*
	// 生年月日 年
	'birth_year'        :   function(data) {
	if(!data)
	return false;
	return true;
	},

// 生年月日 月
'birth_month'       :   function(data) {
if(!data)
return false;
return true;
},

// 生年月日 日
'birth_day'       :   function(data) {
if(!data)
return false;
return true;
},
*/

	// 個人情報保護法のチェック
	'privacy'       :   function() {
		if(!$(":input[name=privacy]").is(":checked")) {
			$("label[for='privacy']").css("background", inputColorCode.error);
			return 'privacyPolicyNotChecked';
		}
		return true;
	},

	// 商品選択のチェック
	'easybuy_value'        :  function(data) {
		if(!parseInt($("option:selected", data).val())) return 'ItemNotSelected';
		return true;
	},

	// 配送ペース
	'regury_pase'       :   function(data) {
		var request_flag = $("#easybuy_value option:selected").attr("request_select");
		if(request_flag == 1){
			if($("option:selected", data).val() == ""){
				return "reguryPaseNotSelected";
			}else{
				return true;
			}
		}else{
			return true;
		}
	}

	// 性別のチェック
	/*
	'sex'           :   function() {
	if(!$("#man:input").is(":checked") && !$("#woman:input").is(":checked"))
	return false;
	return true;
	}
	*/
};


/*
 * 別住所入力フォームエラーチェック用オブジェクト
 */
var check2 = {

    // 空文字チェック用正規表現
    spaceRegExp     :   /(\s|\t|\r|\n|　)*/g,

    // 電話番号チェック用正規表現
    phoneRegExp     :   /^\d{9,11}$/,

    // メールアドレスチェック用正規表現
    mailRegExp      :   /^([a-zA-Z0-9])+([a-zA-Z0-9\._-])*@([a-zA-Z0-9_-])+([a-zA-Z0-9\._-]+)+$/,

    // カタカナ入力チェック用正規表現
    kanaRegExp      :   /^[ァ-ロワヲンー]*$/,
    errorCoupon     : "",
    // エラーメッセージフラグ
    messageFlag     :   false,
    'family_name2'       :   function(data) {
        if(!data.replace(this.spaceRegExp, ''))
            return 'familyNameEmpty2';
        return true;
    },

    // 名
    'given_name2'        :   function(data) {
        if(!data.replace(this.spaceRegExp, ''))
            return 'givenNameEmpty2';
        return true;
    },

    // 姓カナ
    'family_name_kana2'  :   function(data) {
        if(!data.replace(this.spaceRegExp, ''))
            return 'familyNameKanaEmpty2';
        else if(!this.kanaRegExp.test(data.replace(this.spaceRegExp, '')))
            return 'familyNameKanaFormat2';
        return true;
    },

    // 名カナ
    'given_name_kana2'   :   function(data) {
        if(!data.replace(this.spaceRegExp, ''))
            return 'givenNameKanaEmpty2';
        else if(!this.kanaRegExp.test(data.replace(this.spaceRegExp, '')))
            return 'givenNameKanaFormat2';
        return true;
    },

    // 郵便番号
    'postal_code2'       :   function(data) {
        if(!/^\d{7}$/.test(data.replace(/\-/g, '')))
            return 'postalCodeFormat2';
        return true;
    },

    // 住所1
    'new_address1'          :   function(data) {
        if(!data.replace(this.spaceRegExp, ''))
            return 'address1Empty2';
        return true;
    },

    // 電話番号
    'tel2'               :   function(data) {
        if(!this.phoneRegExp.test(data.replace(/\-/g, '')))
            return 'phoneFormat2';
        return true;
    },

    // 都道府県
    'pref2'              :   function(data) {
        if(!data)
            return 'prefNotSelected2';
        return true;
    }
};

/*
 * 入力フォームのイベントリスナ設定
 */
$(':input[type=text], :input[type=radio], :input[type=checkbox]').bind({
    focus   :   function() {
        $(this).css('background', inputColorCode.focus);
    },

    blur    :   function() {
        $(this).css('background', inputColorCode.normal);
    }
});

$('select').change(function(){
    $(this).css('background', inputColorCode.normal);
});

$(":input[name=sex]").change(function() {
    $("label[for=man],label[for=woman]").css('background', inputColorCode.normal);
});

$(":input[name=privacy]").change(function() {
    $("label[for=privacy]").css('background', inputColorCode.normal);
});

$(":input[name=payment]").change(function() {
    $("label[name=payment]").css('background', inputColorCode.normal);
});


/*
 * 申し込むボタンのサブミット
 */
$("#sub").live("click",function() {

    check.messageflag = false;

    var errors = [];
    var code = false;
    $(":input").each(function(){
        if(typeof check[this.name] == 'function') {

            switch(this.name) {

                case 'easybuy_value':
                case 'regury_pase':
                    code = check[this.name]($(":input[name='"+ this.name +"']"));
                    break;

                default:
                    code = check[this.name](this.value);
                    break;
            }

            if(code != true) {
                $(this).css('background', inputColorCode.error);
                errors.push(code);
            }
        }

        //別住所にチェックがあったら
        if($("#new_add_flag:checked").val()) {
            if(typeof check2[this.name] == 'function') {
                code = check2[this.name](this.value);
                if(code != true) {
                    $(this).css('background', inputColorCode.error);
                    errors.push(code);
                }
            }
        }

    });

    // 性別のチェック
    /*
    if(!check.sex()) {
        $("label[for=man]").css('background', inputColorCode.error);
        $("label[for=woman]").css('background', inputColorCode.error);
        check.messageflag = true; // エラーメッセージを表示するフラグ
    }
    */

    // 決済方法のチェック
    if(!$(":input[name=payment]:checked").val()) {
        $("span#reg_payment label").css('background', inputColorCode.error);
        errors.push("paymentNotSelected"); // エラーメッセージを表示するフラグ
    }

	/*****************************************************************************
	* アンケート処理
	*****************************************************************************/
	var free_count = $("#free_count").val();
	var ferrors           = new Array(),
			title = "";
	if(free_count > 0){
		var mid = "";
		$(".free_master_ids").each(function(){

			mid = $(this).val();

			var free_required  = $("#free_required"+ mid +"").val();
			var free_type      = $("#free_type"+ mid +"").val();
			var free_title     = $("#free_title"+ mid +"").val();

			//必須項目であれば
			if(free_required === "2"){

				var free_data     = $("#free_data"+ mid +"").val();

				//テキストタイプ
				if(free_type === "text"){
					if(free_data === ""){
						ferrors.push(free_title + "を入力してください");
						$("#free_data"+ mid +"").css("background-color","#ffaeae");
					}
				}

				//テキストボックス
				if(free_type === "textarea"){
					if(free_data === ""){
						ferrors.push(free_title + "を入力してください");
						$("#free_data"+ mid +"").css("background-color","#ffaeae");
					}
				}

				//チェックボックス
				if(free_type === "checkbox"){
					var num = 0;
					$("[name='free_data["+ mid +"][]']:checked").each(function() {
						var flag = $(this).val();
						if(flag !== ""){
							num = parseInt(num) + parseInt(1);
						}
					});

					if(num === 0){
						ferrors.push(free_title + "を選択してください");
						$("#checkbox").css("background-color","#ffaeae");
					}
				}

			}
			title = free_title;

		});
	}
	checkCouponCode($("#coupon_code").val(), title, $("#easybuy_value").val(),
			$("#regury_pase").val(), $("#item_num").val(), $("input[name=email]").val()).done(function() {
		if (check2.errorCoupon != "") {
			ferrors.push((check2.errorCoupon).substring(1));
		}
		if(errors.length > 0 || ferrors.length > 0 ) {

			var offset = $("#inputForm").offset().top;
			$("html, body").animate({scrollTop: offset}, 700, 'easeOutExpo');
			$("tr.errors td.errorMessage").html("");

			for(var i in errors) {
				$("tr.errors td.errorMessage").append("<div>"+ check.errorsMessage[errors[i]] +"</div>");
				$(".errors").show();
			}

			if(ferrors.length > 0){
				$.each(ferrors, function(i,val){
					$("tr.errors td.errorMessage").append("<div>"+ val +"</div>");
					$(".errors").show();
				});
			}

			// エラーがなければサブミット
		} else {
			$("#inputForm").submit();
		}
	});
	/*****************************************************************************
	* アンケート処理
	*****************************************************************************/

	// ひとつでもエラーがあれば、メッセージを表示

	return false;
});


/*
 * ２回目購入用検索フォームを非表示にしておく
 */
if(!$(":input[name=find_addr]").is(':checked')) {
	$(".find_addr").hide();
}


/*
 * ２回目購入用チェックボックスにチェックされたら、入力フォームを表示
 */
$(":input[name=find_addr]").click(function(){
	if($(this).is(":checked")) $(".find_addr").show();
	else $(".find_addr").hide();
});


/*
 * 別送付先フォームを非表示にしておく
 */
if(!$("#new_add_flag").is(':checked')) {
	$(".new_add_area").hide();
}

/*
 * 別送付先にチェックされたら、入力フォームを表示
 */
$("#new_add_flag").change(function(){
	if($(this).is(":checked")) $(".new_add_area").show();
	else $(".new_add_area").hide();
});


/*
 * POST時のエラー遷移
 */
if($("input[name=p_reg_val]").val() != "") {
	var i = $("#inputForm").index(this);
	var p = $("#inputForm").eq(i).offset().top;
	$('html,body').animate({ scrollTop: p }, 'fast');
}


/*
 * クレジット決済の入力フォーム非表示
 */
if(!$(":input[name=payment][value=1]").is(":checked")) {
	$(".creditInputForm").hide();
}

/*
 * 代引き手数料(メール便用デフォルト)
 */
if(!$(":input[name=payment][value=2]").is(":checked")) {
	$(".mailSendForm").hide();
}

/*
 * 銀行振り込み(デフォルト)
 */
if(!$(":input[name=payment][value=3]").is(":checked")) {
	$(".bankForm").hide();
}


/*
 * コンビニ決済の入力フォーム非表示
 */
if(!$(":input[name=payment][value=4]").is(":checked")) {
	$(".convenienceForm").hide();
}

/*
 * NP後払い決済の入力フォーム非表示
 */
if(!$(":input[name=payment][value=5]").is(":checked")) {
	$(".npForm").hide();
}

/*
 * ニッセン＠払い決済の入力フォーム非表示
 */
if(!$(":input[name=payment][value=6]").is(":checked")) {
	$(".nissenForm").hide();
}

/*
 * 後払い.comの入力フォーム非表示
 */
if(!$(":input[name=payment][value=7]").is(":checked")) {
	$(".atobaraiForm").hide();
}

/*
 * クロネコ後払いの入力フォーム非表示
 */
if(!$(":input[name=payment][value=8]").is(":checked")) {
	$(".kuroatoForm").hide();
}

/*
 * 決済変更時の入力フォーム表示切替
 */
$(":input[name=payment]").live("change", function() {

	$("span#reg_payment label").css("background", inputColorCode.normal);
	$(".creditInputForm").hide();
	$(".convenienceForm").hide();
	$(".npForm").hide();
	$(".mailSendForm").hide();
	$(".bankForm").hide();
	$(".nissenForm").hide();
	$(".atobaraiForm").hide();
	$(".kuroatoForm").hide();

	switch($(this).val()) {
		// クレジット決済用フォーム表示
		case '1':
			$(".creditInputForm").show();
			break;

		// 代引き手数料(メール便用デフォルト)
		case '2':
			$(".mailSendForm").show();
			break;

		// 銀行振り込み(デフォルト)
		case '3':
			$(".bankForm").show();
			break;

		// コンビニ決済用フォーム表示
		case '4':
			$(".convenienceForm").show();
			break;

		// NP後払い決済用フォーム表示
		case '5':
			$(".npForm").show();
			break;

		// ニッセン＠払い決済用フォーム表示
		case '6':
			$(".nissenForm").show();
			break;

		// 後払い.com決済用フォーム表示
		case '7':
			$(".atobaraiForm").show();
			break;

		// クロネコ後払い決済用フォーム表示
		case '8':
			$(".kuroatoForm").show();
			break;

		default:
			break;
	}
});


/*
 * メールアドレスと電話番号から、お届け先情報の取得
 */
var getAddrByMailAndPhone = function(email, phone) {
	var df = $.Deferred();

	$.ajax({
		url        :  '/ajax/find-addr',
		dataType   :  'json',
		type       :  'get',
		data       :  {
			email  :  email,
			phone  :  phone
		},
		cache      :  false,
		success    :  function(json) {

			if(json) {
				// お名前・フリガナの挿入
				$(":input[name=family_name]").val(htmlspecialchars(json.first_name)).css('background', inputColorCode.normal);
				$(":input[name=given_name]").val(htmlspecialchars(json.last_name)).css('background', inputColorCode.normal);
				$(":input[name=family_name_kana]").val(htmlspecialchars(json.first_name_kana)).css('background', inputColorCode.normal);
				$(":input[name=given_name_kana]").val(htmlspecialchars(json.last_name_kana)).css('background', inputColorCode.normal);

				// 住所の挿入
				$(":input[name=pref] option").attr("selected", false);
				$(":input[name=pref]").css('background', inputColorCode.normal);
				$(":input[name=pref] option[value="+ json.pref_id +"]").attr('selected', true).css('background', inputColorCode.normal);
				$(":input[name=postal_code]").val(htmlspecialchars(json.postal_code)).css('background', inputColorCode.normal);
				$(":input[name=address1]").val(htmlspecialchars(json.address1)).css('background', inputColorCode.normal);
				$(":input[name=address2]").val(htmlspecialchars(json.address2)).css('background', inputColorCode.normal);

				// 電話番号の挿入
				$(":input[name=tel]").val(htmlspecialchars(json.phone1 || json.phone2)).css('background', inputColorCode.normal);

				// メールアドレスの挿入
				$(":input[name=email]").val(htmlspecialchars(json.mail_address)).css('background', inputColorCode.normal);

				/*
				* 請求先の住所処理
				*/
				if(json.a_first_name != null){
					//別の住所を入力するのチェックを入れて入力フォームを出す処理
					$("#new_add_flag").attr("checked", true).trigger("change");
					// お名前・フリガナの挿入
					$(":input[name=family_name2]").val(htmlspecialchars(json.a_first_name)).css('background', inputColorCode.normal);
					$(":input[name=given_name2]").val(htmlspecialchars(json.a_last_name)).css('background', inputColorCode.normal);
					$(":input[name=family_name_kana2]").val(htmlspecialchars(json.a_first_name_kana)).css('background', inputColorCode.normal);
					$(":input[name=given_name_kana2]").val(htmlspecialchars(json.a_last_name_kana)).css('background', inputColorCode.normal);
					// 住所の挿入
					$(":input[name=pref2] option").attr("selected", false);
					$(":input[name=pref2]").css('background', inputColorCode.normal);
					$(":input[name=pref2] option[value="+ json.a_pref +"]").attr('selected', true).css('background', inputColorCode.normal);
					$(":input[name=postal_code2]").val(htmlspecialchars(json.a_postal_code)).css('background', inputColorCode.normal);
					$(":input[name=new_address1]").val(htmlspecialchars(json.a_address1)).css('background', inputColorCode.normal);
					$(":input[name=new_address2]").val(htmlspecialchars(json.a_address2)).css('background', inputColorCode.normal);
					// 電話番号の挿入
					$(":input[name=tel2]").val(htmlspecialchars(json.a_phone1)).css('background', inputColorCode.normal);
				}else{
					//別の住所を入力するのチェックを外して入力フォームを消す処理
					$("#new_add_flag").attr("checked", false).trigger("change");
					// お名前・フリガナを空にする
					$(":input[name=family_name2]").val("");
					$(":input[name=given_name2]").val("");
					$(":input[name=family_name_kana2]").val("");
					$(":input[name=given_name_kana2]").val("");
					// 住所を空にする
					$(":input[name=pref2] option").attr("selected", false);
					$(":input[name=postal_code2]").val("");
					$(":input[name=new_address1]").val("");
					$(":input[name=new_address2]").val("");
					// 電話番号を空にする
					$(":input[name=tel2]").val("");
				}
			}
			df.resolve();
		}
	});
	return df.promise();
};

var find_phone = '', find_mail = '';
$(":input[name=find_addr_submit]").click(function() {
	var findAddrObj = $(this);

	find_phone = $(":input[name=find_phone]").val();
	find_mail  = $(":input[name=find_mail]").val();

	if(check.phoneRegExp.test(find_phone.replace(/\-/g, "")) && check.mailRegExp.test(find_mail)) {

		// ローディング画像の表示
		$("+img.loader", this).fadeIn("fast");

		getAddrByMailAndPhone(find_mail, find_phone).done(function() {
			$("+img.loader", findAddrObj).fadeOut("slow");
		});
	}
});


// タブ切り替え時
$("#tab li").live('click', function() {
	check.buyTypeNum = $("#tab li").index(this);
	$(".errors").hide();
	$(":input").css("background", inputColorCode.normal);
});

//通常時
if($(".reg_num").val() != 1){
	check.buyTypeNum = $(".reg_num").val();
	$(".errors").hide();
	$(":input").css("background", inputColorCode.normal);
}

/*
 * @author: Huyen Nguyen <nguyen.huyen@mulodo.com>
 * f: Validate coupon code
 * @create: 2015/10/02
 */

function checkCouponCode($coupon_code, $free_title, $easybuy_value, $regury_pase, $item_num, $email){
	var df = $.Deferred();

	$.ajax({
		url:'/easybuy/check-coupon',
		dataType:'json',
		type:'POST',
		data:{
			coupon_code: $coupon_code,
			free_title: $free_title,
			easybuy_value: $easybuy_value,
			regury_pase: $regury_pase,
			item_num: $item_num,
			email: $email
		},
		cache: false,
		success: function (json) {
			check2.errorCoupon = json;
			if (json) {
				$("tr.errors td.errorMessage").append("<div>"+ json +"</div>");
				$("#coupon_code").css('background', inputColorCode.error);
			}

			df.resolve();
		}
	});
	return df.promise();
}